@@ -4,11 +4,12 @@
 
 # flake8: noqa
 
-from . import aa, automation, misc, noise, scale, util
+from . import aa, automation, misc, noise, scale, descale, util
 from .aa import *
 from .automation import *
 from .auto.convert import *
 from .misc import *
 from .noise import *
 from .scale import *
+from .descale import *
 from .util import *
